@@ -18,7 +18,7 @@
     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-__version__ = "0.0.1"
+__version__ = "0.0.5"
 
 import argparse
 import datetime
@@ -31,7 +31,6 @@ import re
 import requests
 import tldextract
 import copy
-
 import ptlibs.ptjsonlib as ptjsonlib
 import ptlibs.ptmisclib as ptmisclib
 from ptthreads import ptthreads
@@ -50,7 +49,7 @@ class ptwebdiscover():
         self.args.position, self.args.url = self.get_star_position(self.args.url)
         self.args.headers           = ptmisclib.get_request_headers(args)
         self.args.proxies           = {"http": args.proxy, "https": args.proxy}
-        self.args.charset           = ptmisclib.get_charset(args.charsets)
+        self.args.charset           = ptmisclib.get_charset(["lowercase"]) if not args.charsets and not args.wordlist else ptmisclib.get_charset(args.charsets)
         self.args.parse             = args.parse or args.parse_only
         self.args.begin_with        = args.begin_with if args.begin_with else ""
         self.args.length_max        = args.length_max if args.length_max else 99 if args.wordlist else 6 
@@ -99,7 +98,7 @@ class ptwebdiscover():
             self.counter = 0
             self.start_dict_time = time.time()
             ptmisclib.clear_line_ifnot(condition = self.args.json)
-            ptmisclib.ptprint( ptmisclib.out_title_ifnot("Check " + self.domain_with_protocol + self.directory, self.args.json))
+            ptmisclib.ptprint_( ptmisclib.out_title_ifnot("Check " + self.domain_with_protocol + self.directory, self.args.json))
             if not self.check_posibility_testing():
                 self.printlock.lock_print( ptmisclib.out_ifnot("Not posible to check this directory. Use -sy, -sn or -sc parameter.", "ERROR", self.args.json), end="\n", clear_to_eol=True)
                 continue
@@ -120,7 +119,7 @@ class ptwebdiscover():
             self.findings2 = self.findings.copy()
             self.prepare_backup()
             ptmisclib.clear_line_ifnot(condition = self.args.json)
-            ptmisclib.ptprint( ptmisclib.out_title_ifnot("Search for backups", self.args.json))
+            ptmisclib.ptprint_( ptmisclib.out_title_ifnot("Search for backups", self.args.json))
             self.ptthreads.threads(self.findings2, self.search_backups, self.args.threads)
             if self.args.recurse:
                 self.process_notvisited_urls()
@@ -128,7 +127,7 @@ class ptwebdiscover():
             self.prepare_backup()
             self.search_for_backup_of_all(self.domain)
         self.output_result(self.findings, self.findings_details, self.technologies)
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Finished in {ptmisclib.time2str(time.time()-self.start_time)} - discovered: {len(self.findings)} items", "INFO", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Finished in {ptmisclib.time2str(time.time()-self.start_time)} - discovered: {len(self.findings)} items", "INFO", self.args.json))
 
     def dictionary_discover(self, line):
         for extension in self.args.extensions:
@@ -163,7 +162,7 @@ class ptwebdiscover():
         #TODO Run brute force or directory for every new directory
         if self.args.parse:
             ptmisclib.clear_line_ifnot(condition = self.args.json)
-            ptmisclib.ptprint( ptmisclib.out_title_ifnot("Checking not visited sources", self.args.json))
+            ptmisclib.ptprint_( ptmisclib.out_title_ifnot("Checking not visited sources", self.args.json))
             while True:
                 if not self.get_notvisited_urls():
                     break
@@ -406,7 +405,7 @@ class ptwebdiscover():
         for wl in args.wordlist:
             with open(wl, encoding='utf-8', errors='ignore') as f:
                 wordlist = list(f)
-                wordlist = [item.strip() for item in wordlist if item.startswith(self.args.begin_with) and len(item) >= self.args.length_min and len(item) <= self.args.length_max]
+                wordlist = [item.strip() for item in wordlist if item.startswith(self.args.begin_with) and len(item) >= self.args.length_min and len(item) <= self.args.length_max]    
             if args.case_insensitive or "lowercase" in args.charsets:
                 wordlist = [item.lower() for item in wordlist]
                 wordlist_complete += wordlist
@@ -441,8 +440,8 @@ class ptwebdiscover():
             return c_t, c_l
 
     def prepare_backup(self):
-        self.backup_exts       = [".bak", ".old", ".zal", ".zip", ".rar", ".tar", ".tar.gz"]
-        self.backup_all_exts   = [".zip", ".rar", ".tar", ".tar.gz", ".sql", ".sql.gz"]
+        self.backup_exts       = [".bak", ".old", ".zal", ".zip", ".rar", ".tar", ".tar.gz", ".tgz", ".7z"]
+        self.backup_all_exts   = [".zip", ".rar", ".tar", ".tar.gz", ".tgz", ".7z", ".sql", ".sql.gz"]
         self.delimeters        = ["", "_", ".", "-"]
         self.backup_chars      = ["_", "~", ".gz"]
         self.wordlist          = []
@@ -465,7 +464,7 @@ class ptwebdiscover():
     
     def search_for_backup_of_all(self, domain):
         ptmisclib.clear_line_ifnot(condition = self.args.json)
-        ptmisclib.ptprint( ptmisclib.out_title_ifnot("Search for completed backups of the website", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_title_ifnot("Search for completed backups of the website", self.args.json))
         self.start_dict_time = time.time()
         self.counter = 0
         self.keyspace = len(self.backup_all_exts) * len(domain.split(".")) * len(self.delimeters) * len(domain.split(".")) / 2 - (len(self.backup_all_exts) * (len(self.delimeters) - 1))
@@ -517,14 +516,14 @@ class ptwebdiscover():
         if findings:
             if self.args.without_domain:
                 findings = [url.replace(self.domain_with_protocol, "") for url in findings]
-            ptmisclib.ptprint( ptmisclib.out_title_ifnot("Discovered sources", self.args.json))
+            ptmisclib.ptprint_( ptmisclib.out_title_ifnot("Discovered sources", self.args.json))
             if self.args.tree:
                 self.output_tree(findings)
             else:
                 self.output_list(findings, findings_details)
             ptmisclib.clear_line_ifnot(condition=self.args.json)
         if technologies:
-            ptmisclib.ptprint( ptmisclib.out_title_ifnot("Discovered technologies", self.args.json))
+            ptmisclib.ptprint_( ptmisclib.out_title_ifnot("Discovered technologies", self.args.json))
             self.output_list(technologies)
             ptmisclib.clear_line_ifnot(condition=self.args.json)
 
@@ -549,21 +548,21 @@ class ptwebdiscover():
                 for line_detail in line_list_details:
                     if line_detail[0] == line:
                         is_detail = True
-                        ptmisclib.ptprint( ptmisclib.out_ifnot("[" + str(line_detail[1]) + "]  " + line + "\n", condition=self.args.json), end="")
+                        ptmisclib.ptprint_( ptmisclib.out_ifnot("[" + str(line_detail[1]) + "]  " + line + "\n", condition=self.args.json), end="")
                         if self.args.output:
                             output_file_detail.write("[" + str(line_detail[1]) + "]  " + line + "\r\n")
                         try:
                             for key, value in line_detail[2].items():
                                 if self.args.output:
                                     output_file_detail.write(" " * 7 + key + " : " + value + "\r\n")
-                                ptmisclib.ptprint( ptmisclib.out_ifnot(" " * 7 + key + " : " + value, "ADDITIONS", condition=self.args.json, colortext=True))
+                                ptmisclib.ptprint_( ptmisclib.out_ifnot(" " * 7 + key + " : " + value, "ADDITIONS", condition=self.args.json, colortext=True))
                             break
                         except:
                             pass
-                ptmisclib.ptprint( ptmisclib.out_ifnot("\n", condition=self.args.json))
+                ptmisclib.ptprint_( ptmisclib.out_ifnot("\n", condition=self.args.json))
             if not is_detail:
-                ptmisclib.ptprint( ptmisclib.out_ifnot(line, condition=self.args.json))
-                #TODO opravit JSON
+                ptmisclib.ptprint_( ptmisclib.out_ifnot(line, condition=self.args.json))
+                #TODO repaire JSON
                 if self.args.json:
                     print(line)
                 if self.args.output:
@@ -669,7 +668,7 @@ class ptwebdiscover():
             response = requests.request(method, url, headers=headers, proxies=proxies, verify=False, allow_redirects=True, auth=auth)
         except:
             ptmisclib.end_error("Server not found", self.json_no, self.ptjsonlib, self.args.json)
-        if self.args.without_availability:
+        if self.args.is_star or self.args.without_availability:
             return response
         if response.status_code == 404:
             ptmisclib.end_error("Returned status code 404. Check url address.", self.json_no, self.ptjsonlib, self.args.json)
@@ -699,7 +698,7 @@ class ptwebdiscover():
             self.domain_protocol = "https"
             self.args.position += 1
         else:
-            ptmisclib.ptprint( ptmisclib.out_ifnot(f"Returned status code {response.status_code}. Site redirected to {target_location}. Check target in -u option.\n", "ERROR", self.args.json), end="\n", clear_to_eol=True)
+            ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Returned status code {response.status_code}. Site redirected to {target_location}. Check target in -u option.\n", "ERROR", self.args.json), end="\n", clear_to_eol=True)
         return (self.args.url, self.args.position)
 
     def add_missing_scheme(self, url):
@@ -718,27 +717,27 @@ class ptwebdiscover():
         return cookies
 
     def print_configuration(self, args):
-        ptmisclib.ptprint( ptmisclib.out_title_ifnot("Settings overview", self.args.json))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"URL................: {self.args.nochanged_url}", "INFO", self.args.json))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Discovery-type.....: Brute force", "INFO", self.args.json or args.wordlist or args.parse_only or args.backups_only))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Discovery-type.....: Complete backups only", "INFO", self.args.json or not args.backups_only))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Discovery-type.....: Dictionary", "INFO", self.args.json or not args.wordlist))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Discovery-type.....: Crawling", "INFO", self.args.json or not args.parse_only))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Wordlist...........: {str(args.wordlist)}", "INFO", self.args.json or not args.wordlist))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Extensions.........: {self.args.extensions}", "INFO", self.args.json))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Method.............: {self.args.method}", "INFO", self.args.json))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"String starts......: {self.args.begin_with}", "INFO", self.args.json or not self.args.begin_with))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Is in response.....: {self.args.string_in_response}", "INFO", self.args.json or not self.args.string_in_response))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Is not in response.: {self.args.string_not_in_response}", "INFO", self.args.json or not self.args.string_not_in_response))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Charset............: {''.join(self.args.charset)}", "INFO", self.args.json or args.wordlist or args.parse_only))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Length-min.........: {self.args.length_min}", "INFO", self.args.json or args.parse_only))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Length-max.........: {self.args.length_max}", "INFO", self.args.json or args.parse_only))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Keyspace...........: {self.keyspace}", "INFO", self.args.json or args.parse_only))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Delay..............: {self.args.delay}s", "INFO", self.args.json))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Threads............: {self.args.threads}", "INFO", self.args.json))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Recurse............: {self.args.recurse}", "INFO", self.args.json))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Parse content......: {self.args.parse}", "INFO", self.args.json))
-        ptmisclib.ptprint( ptmisclib.out_ifnot(f"Search for backups.: {self.args.backups}", "INFO", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_title_ifnot("Settings overview", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"URL................: {self.args.nochanged_url}", "INFO", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Discovery-type.....: Brute force", "INFO", self.args.json or args.wordlist or args.parse_only or args.backups_only))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Discovery-type.....: Complete backups only", "INFO", self.args.json or not args.backups_only))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Discovery-type.....: Dictionary", "INFO", self.args.json or not args.wordlist))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Discovery-type.....: Crawling", "INFO", self.args.json or not args.parse_only))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Wordlist...........: {str(args.wordlist)}", "INFO", self.args.json or not args.wordlist))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Extensions.........: {self.args.extensions}", "INFO", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Method.............: {self.args.method}", "INFO", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"String starts......: {self.args.begin_with}", "INFO", self.args.json or not self.args.begin_with))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Is in response.....: {self.args.string_in_response}", "INFO", self.args.json or not self.args.string_in_response))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Is not in response.: {self.args.string_not_in_response}", "INFO", self.args.json or not self.args.string_not_in_response))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Charset............: {''.join(self.args.charset)}", "INFO", self.args.json or args.wordlist or args.parse_only))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Length-min.........: {self.args.length_min}", "INFO", self.args.json or args.parse_only))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Length-max.........: {self.args.length_max}", "INFO", self.args.json or args.parse_only))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Keyspace...........: {self.keyspace}", "INFO", self.args.json or args.parse_only))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Delay..............: {self.args.delay}s", "INFO", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Threads............: {self.args.threads}", "INFO", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Recurse............: {self.args.recurse}", "INFO", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Parse content......: {self.args.parse}", "INFO", self.args.json))
+        ptmisclib.ptprint_( ptmisclib.out_ifnot(f"Search for backups.: {self.args.backups}", "INFO", self.args.json))
 
 def get_help():
     return [
@@ -763,7 +762,7 @@ def get_help():
         ]},
         {"options": [
             ["-u",  "--url",                    "<url>",            "URL for test (usage of a star character as anchor)"],
-            ["-ch", "--charsets",               "<charsets>",       "Specify charset for brute force (example: lowercase,uppercase,numbers,[custom_chars])"],
+            ["-ch", "--charsets",               "<charsets>",       "Specify charset fro brute force (example: lowercase,uppercase,numbers,[custom_chars])"],
             ["",    "",                         "",                 "Modify wordlist (lowercase,uppercase,capitalize)"],
             ["-lm", "--length-min",             "<length-min>",     "Minimal length of brute-force tested string (default 1)"],
             ["-lx", "--length-max",             "<length-max>",     "Maximal length of brute-force tested string (default 6 bf / 99 wl"],
@@ -818,7 +817,7 @@ def get_help():
 def parse_args():
     parser = argparse.ArgumentParser(add_help=False, usage=f"{SCRIPTNAME} <options>")
     parser.add_argument("-u",  "--url", type=str)
-    parser.add_argument("-ch", "--charsets", type=str, nargs="+", default=["lowercase"])
+    parser.add_argument("-ch", "--charsets", type=str, nargs="+", default=[])
     parser.add_argument("-lm", "--length-min", type=int, default=1)
     parser.add_argument("-lx", "--length-max", type=int)
     parser.add_argument("-w",  "--wordlist", type=str, nargs="+")
